.. fastnumbers documentation master file, created by
   sphinx-quickstart on Thu Jul 17 21:01:29 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

fastnumbers: Super-fast and clean conversions to numbers
========================================================

    - Source Code: https://github.com/SethMMorton/fastnumbers
    - Downloads: https://pypi.org/project/fastnumbers/
    - Documentation: https://fastnumbers.readthedocs.io/

Please see the `GitHub main page <https://github.com/SethMMorton/fastnumbers#fastnumbers>`_
for everything else, including

    - Quick start
    - High-level algortihm overview
    - Installation instructions
    - Testing instructions

.. toctree::
   :maxdepth: 2
   :numbered:

   timing.rst
   api.rst
   changelog.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

